%define majver %(echo %version | cut -d. -f 1-2)
Name:          NetworkManager
Version:       1.2.2
Release:       1mamba
Summary:       A hardware level network management tool integrated with D-Bus
Group:         System/Kernel and Hardware
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://wiki.gnome.org/Projects/NetworkManager
Source:        http://ftp.gnome.org/pub/GNOME/sources/NetworkManager/%{majver}/%{name}-%{version}.tar.xz
Source1:       NetworkManager-0.8.2-polkit-localauthority.patch
Patch0:        NetworkManager-0.9.10.0-stop-before-dbus.patch
Patch7:        %{name}-0.9.4.0-wpa_supplicant_longer_timeout.patch
Patch8:        NetworkManager-1.0.8-kernel-headers-3.17.patch
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: ModemManager-devel
BuildRequires: glibc-devel
BuildRequires: libdbus-devel
BuildRequires: libdbus-glib-devel
BuildRequires: libdw-devel
BuildRequires: libffi-devel
BuildRequires: libgcrypt-devel
BuildRequires: libglib-devel
BuildRequires: libgpg-error-devel
BuildRequires: liblzma-devel
BuildRequires: libndp-devel
BuildRequires: libnewt-devel
BuildRequires: libnl-devel
BuildRequires: libnspr-devel
BuildRequires: libnss-devel
BuildRequires: libpolkit-devel
BuildRequires: libreadline-devel
BuildRequires: libselinux-devel
BuildRequires: libsoup-devel
BuildRequires: libsqlite-devel
BuildRequires: libsystemd-devel
BuildRequires: libteam-devel
BuildRequires: libtermcap-devel
BuildRequires: libudev-devel
BuildRequires: libuuid-devel
BuildRequires: libxml2-devel
BuildRequires: libz-devel
## AUTOBUILDREQ-END
BuildRequires: libsodium-devel >= 1.0.8-1mamba
BuildRequires: gettext-devel
BuildRequires: pkgconfig
BuildRequires: dhcdbd
BuildRequires: dhcp-client
BuildRequires: libiw-devel
BuildRequires: ppp-devel
Requires:      iproute >= 2.6.11
Requires:      wpa_supplicant >= 0.7.3-3mamba
Requires:      ppp >= 2.4.5-5mamba
Requires:      dhcpclient
Requires:      libnm = %{?epoch:%epoch:}%{version}-%{release}
Requires(post):dbus
Requires(post):systemd-core
Conflicts:     wicd
BuildRoot:     %{_tmppath}/%{name}-%{version}-root

%description
NetworkManager is a hardware level network management tool integrated with the D-Bus subsystem.

%package -n libnm
Summary:       Libraries used by %{name}
Group:         System/Libraries

%description -n libnm
NetworkManager is a hardware level network management tool integrated with the D-Bus subsystem.
This package contains the shared libraries.

%package -n libnm-devel
Summary:       Devel package for %{name}
Group:         Development/Libraries
Requires:      libnm = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     NetworkManager-devel
Provides:      NetworkManager-devel

%description -n libnm-devel
NetworkManager is a hardware level network management tool integrated with the D-Bus subsystem.
This package contains static libraries and header files need for development.

%package apidocs
Group:         Documentation
Summary:       %{name} API documentation
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      gtk-doc

%description apidocs
This package includes the %{name} API documentation.

%debug_package

%prep
%setup -q
%patch0 -p1
#%patch8 -p1

%build
%configure \
   --with-udev-dir=/lib/udev \
   --with-tests \
   --enable-doc \
   --enable-gtk-doc \
   --enable-ifcfg-rh \
   --with-systemdsystemunitdir=`pkg-config systemd --variable=systemdsystemunitdir` \
   --with-session-tracking=systemd \
   --with-modem-manager-1 \
   --enable-bluez4 \
   --enable-teamdctl \
   --enable-polkit \
   --enable-modify-system \
   --enable-concheck \
   LIBS="-ltermcap"

#   --enable-wimax \
#   --with-distro=redhat \

%make

%install
[ "%{buildroot}" != / ] && rm -rf %{buildroot}
%makeinstall

#install -m0755 test/.libs/nm-online %{buildroot}%{_bindir}/nm-online
install -D -m0644 %{SOURCE1} \
   %{buildroot}%{_sysconfdir}/polkit-1/localauthority/50-local.d/10-org-freedesktop-network-manager-settings.pkla
rm -f %{buildroot}%{_libdir}/libnm-*.a

install -d -m0755 %{buildroot}%{_sysconfdir}/NetworkManager/VPN
install -d -m0755 %{buildroot}%{_sysconfdir}/NetworkManager/system-connections

%{find_lang} %{name}

cat > %{buildroot}%{_sysconfdir}/NetworkManager/NetworkManager.conf << _EOF
[main]
plugins=ifcfg-rh,keyfile
_EOF


%clean
[ "%{buildroot}" != / ] && rm -rf %{buildroot}

%post
/sbin/ldconfig
if [ $1 -ge 1 ]; then
   # clean old sysv broken links
   find /etc/rc[0-6].d/ -type l -xtype l -exec rm -f {} \;
   sed -i "s|^plugins=keyfile$|plugins=ifcfg-rh,keyfile|" %{_sysconfdir}/NetworkManager/NetworkManager.conf
   systemctl -q enable NetworkManager
   systemctl -q enable NetworkManager-dispatcher
   systemctl -q daemon-reload
fi
if [ $1 -eq 1 ]; then
   # new install
   systemctl -q start NetworkManager
fi
exit 0

%preun
# erase
/sbin/ldconfig
if [ $1 -eq 0 ]; then
   systemctl -q stop NetworkManager-dispatcher
   systemctl -q stop NetworkManager
   systemctl -q disable NetworkManager
   systemctl -q disable NetworkManager-dispatcher
fi
exit 0

%files -f %{name}.lang
%defattr(-,root,root)
%{_sysconfdir}/dbus-1/system.d/*.conf
%{_sysconfdir}/polkit-1/localauthority/50-local.d/10-org-freedesktop-network-manager-settings.pkla
%dir %{_sysconfdir}/NetworkManager
%config(noreplace) %{_sysconfdir}/NetworkManager/NetworkManager.conf
%dir %{_sysconfdir}/NetworkManager/dispatcher.d
%dir %{_sysconfdir}/NetworkManager/VPN
%dir %{_sysconfdir}/NetworkManager/system-connections
%{_sbindir}/NetworkManager
%{_bindir}/nmcli
%{_bindir}/nmtui
%{_bindir}/nmtui-connect
%{_bindir}/nmtui-edit
%{_bindir}/nmtui-hostname
%{_bindir}/nm-online
/lib/udev/rules.d/*.rules
/lib/systemd/system/NetworkManager.service
/lib/systemd/system/NetworkManager-dispatcher.service
/lib/systemd/system/NetworkManager-wait-online.service
/lib/systemd/system/network-online.target.wants/NetworkManager-wait-online.service
%{_datadir}/bash-completion/completions/nmcli
%{_datadir}/polkit-1/actions/org.freedesktop.NetworkManager.policy
%{_datadir}/dbus-1/system-services/org.freedesktop.NetworkManager.service
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_dispatcher.service
#%{_libexecdir}/nm-crash-logger
#%{_datadir}/NetworkManager/gdb-cmd
/var/run/NetworkManager
%{_mandir}/man1/nm-online.1.*
#%{_mandir}/man1/nm-tool.1*
%{_mandir}/man1/nmcli.1*
%{_mandir}/man1/nmtui*.1*
%{_mandir}/man5/NetworkManager.conf.5*
%{_mandir}/man5/nm-settings*.5*
%{_mandir}/man5/nm-system-settings.conf.5*
%{_mandir}/man7/nmcli-examples.7*
%{_mandir}/man8/NetworkManager.8*

%files -n libnm
%defattr(-,root,root)
%{_libexecdir}/nm-iface-helper
%{_libdir}/libnm.so.*
%{_libdir}/libnm-util.so.*
%{_libdir}/libnm-glib-vpn.so.*
%{_libdir}/libnm-glib.so.*
%dir %{_libdir}/NetworkManager
%{_libdir}/NetworkManager/libnm-settings-plugin-ifcfg-rh.la
%{_libdir}/NetworkManager/libnm-settings-plugin-ifcfg-rh.so
%{_libdir}/NetworkManager/libnm-device-plugin-adsl.la
%{_libdir}/NetworkManager/libnm-device-plugin-adsl.so
%{_libdir}/NetworkManager/libnm-device-plugin-bluetooth.la
%{_libdir}/NetworkManager/libnm-device-plugin-bluetooth.so
%{_libdir}/NetworkManager/libnm-device-plugin-wifi.la
%{_libdir}/NetworkManager/libnm-device-plugin-wifi.so
%{_libdir}/NetworkManager/libnm-device-plugin-wwan.la
%{_libdir}/NetworkManager/libnm-device-plugin-wwan.so
%{_libdir}/NetworkManager/libnm-wwan.la
%{_libdir}/NetworkManager/libnm-wwan.so
%{_libdir}/pppd/*/nm-pppd-plugin.la
%{_libdir}/pppd/*/nm-pppd-plugin.so
#%{_libexecdir}/nm-avahi-autoipd.action
%{_libexecdir}/nm-dhcp-helper
%{_libexecdir}/nm-dispatcher
%{_libdir}/girepository-1.0/NM-1.0.typelib
%{_libdir}/girepository-1.0/NMClient-1.0.typelib
%{_libdir}/girepository-1.0/NetworkManager-1.0.typelib
%doc AUTHORS COPYING

%files -n libnm-devel
%defattr(-,root,root)
%{_libdir}/*.la
%{_libdir}/*.so
%dir %{_includedir}/NetworkManager
%{_includedir}/NetworkManager/*.h
%dir %{_includedir}/libnm
%{_includedir}/libnm/*.h
%{_includedir}/libnm-glib/libnm_glib.h
%{_includedir}/libnm-glib/nm-*.h
%{_libdir}/NetworkManager/libnm-device-plugin-team.la
%{_libdir}/NetworkManager/libnm-device-plugin-team.so
%{_libdir}/NetworkManager/libnm-settings-plugin-ibft.la
%{_libdir}/NetworkManager/libnm-settings-plugin-ibft.so
%{_datadir}/gir-1.0/NM-1.0.gir
%{_datadir}/gir-1.0/NMClient-1.0.gir
%{_datadir}/gir-1.0/NetworkManager-1.0.gir
%{_datadir}/vala/vapi/libnm-glib.deps
%{_datadir}/vala/vapi/libnm-glib.vapi
%{_datadir}/vala/vapi/libnm-util.deps
%{_datadir}/vala/vapi/libnm-util.vapi
%{_libdir}/pkgconfig/*.pc
%doc ChangeLog NEWS README TODO

%files apidocs
%defattr(-,root,root)
%dir %{_datadir}/gtk-doc/html/NetworkManager
%{_datadir}/gtk-doc/html/NetworkManager/*
%dir %{_datadir}/gtk-doc/html/libnm-glib
%{_datadir}/gtk-doc/html/libnm-glib/*
%dir %{_datadir}/gtk-doc/html/libnm
%{_datadir}/gtk-doc/html/libnm/*
%dir %{_datadir}/gtk-doc/html/libnm-util
%{_datadir}/gtk-doc/html/libnm-util/*
%dir %{_datadir}/doc/NetworkManager
%dir %{_datadir}/doc/NetworkManager/examples
%{_datadir}/doc/NetworkManager/examples/server.conf

%changelog
* Tue Jun 07 2016 Automatic Build System <autodist@mambasoft.it> 1.2.2-1mamba
- automatic version update by autodist

* Mon May 16 2016 Automatic Build System <autodist@mambasoft.it> 1.2.0-1mamba
- automatic version update by autodist

* Sat Apr 02 2016 Automatic Build System <autodist@mambasoft.it> 1.0.12-1mamba
- automatic version update by autodist

* Mon Feb 29 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.10-2mamba
- rebuilt by autoport with build requirements: libsodium-devel>=1.0.8-1mamba

* Thu Dec 24 2015 Automatic Build System <autodist@mambasoft.it> 1.0.10-1mamba
- automatic version update by autodist

* Fri Nov 27 2015 Automatic Build System <autodist@mambasoft.it> 1.0.8-1mamba
- automatic version update by autodist

* Fri Aug 28 2015 Automatic Build System <autodist@mambasoft.it> 1.0.6-1mamba
- automatic version update by autodist

* Sun Aug 02 2015 Automatic Build System <autodist@mambasoft.it> 1.0.4-1mamba
- automatic version update by autodist

* Wed May 06 2015 Automatic Build System <autodist@mambasoft.it> 1.0.2-1mamba
- automatic version update by autodist

* Sun Dec 28 2014 Automatic Build System <autodist@mambasoft.it> 1.0.0-1mamba
- automatic version update by autodist

* Sat Nov 22 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.10.0-3mamba
- patch systemd service with After=dbus.service to fix blocking shutdowns
- remove sysv initscript

* Thu Oct 16 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.10.0-2mamba
- rebuilt with --with-session-tracking=systemd and more new options

* Fri Jul 04 2014 Automatic Build System <autodist@mambasoft.it> 0.9.10.0-1mamba
- automatic version update by autodist

* Sat Jun 21 2014 Automatic Build System <autodist@mambasoft.it> 0.9.9.98-1mamba
- automatic version update by autodist

* Wed Jun 18 2014 Automatic Build System <autodist@mambasoft.it> 0.9.9.95-1mamba
- automatic version update by autodist

* Thu Apr 24 2014 Automatic Build System <autodist@mambasoft.it> 0.9.8.10-1mamba
- automatic version update by autodist

* Mon Apr 07 2014 Automatic Build System <autodist@mambasoft.it> 0.9.8.9-1mamba
- automatic version update by autodist

* Sun Dec 01 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.8-3mamba
- enable bluez4 support

* Sat Nov 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.8-2mamba
- rebuilt with --with-modem-manager-1 to support ModemManager 1.0

* Fri Oct 11 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.8-1mamba
- automatic version update by autodist

* Tue Oct 01 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.6-1mamba
- automatic version update by autodist

* Sat Sep 14 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.4-1mamba
- automatic version update by autodist

* Wed Sep 11 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.2-3mamba
- also enable NetworkManager-dispatcher service for dispatcher function to work
  (https://bugzilla.redhat.com/show_bug.cgi?id=974811)

* Fri Aug 30 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.2-2mamba
- polkit: allo action org.freedesktop.NetworkManager.settings.modify.system to sysadmin as required by network-manager-applet

* Sat Jun 08 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.2-1mamba
- automatic version update by autodist

* Thu Mar 21 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.0-4mamba
- enable systemd NetworkManager service

* Sun Mar 17 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.0-3mamba
- fix systemdsystemunitdir installation path

* Mon Feb 25 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.8.0-2mamba
- install initscript, no longer installed by default

* Sat Feb 23 2013 Automatic Build System <autodist@mambasoft.it> 0.9.8.0-1mamba
- automatic version update by autodist

* Tue Jan 22 2013 Automatic Build System <autodist@mambasoft.it> 0.9.7.995-1mamba
- automatic version update by autodist

* Sun Oct 29 2012 Automatic Build System <autodist@mambasoft.it> 0.9.6.4-1mamba
- automatic version update by autodist
- source edit: require ppp > 2.4.5-5mamba (with ipv6 support enabled)

* Sat Sep 15 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.6.0-2mamba
- moved typelib files from libnm-devel to libnm

* Tue Aug 07 2012 Automatic Build System <autodist@mambasoft.it> 0.9.6.0-1mamba
- automatic version update by autodist

* Tue Jul 24 2012 Automatic Build System <autodist@mambasoft.it> 0.9.5.96-1mamba
- automatic version update by autodist

* Sat Jun 30 2012 Automatic Build System <autodist@mambasoft.it> 0.9.5.95-1mamba
- automatic version update by autodist

* Sat Jun 09 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.4.0-4mamba
- use lfs patch to fix nmcli issues

* Fri May 18 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.4.0-3mamba
- added upstream patch to fix nmcli (http://cgit.freedesktop.org/NetworkManager/NetworkManager/commit/?id=8a2267ab6b37948a70c10f0af781be4822a54c6b)

* Thu May 03 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.4.0-2mamba
- added patch to raise wpa_supplicant timeout from 25 to 90 seconds
- fixed installation of nm-online tool
- don't restart service on upgrade

* Sat Mar 24 2012 Automatic Build System <autodist@mambasoft.it> 0.9.4.0-1mamba
- automatic version update by autodist

* Mon Mar 19 2012 Automatic Build System <autodist@mambasoft.it> 0.9.3.997-1mamba
- automatic version update by autodist

* Tue Mar 13 2012 Automatic Build System <autodist@mambasoft.it> 0.9.3.995-1mamba
- automatic version update by autodist

* Thu Nov 10 2011 Automatic Build System <autodist@mambasoft.it> 0.9.2.0-1mamba
- automatic version update by autodist

* Sat Oct 29 2011 Automatic Build System <autodist@mambasoft.it> 0.9.1.95-1mamba
- automatic version update by autodist

* Wed Sep 28 2011 Automatic Build System <autodist@mambasoft.it> 0.9.1.90-1mamba
- automatic version update by autodist

* Sun Sep 18 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.9.0-2mamba
- require wpa_supplicant >= 0.7.3-3mamba

* Thu Aug 25 2011 Automatic Build System <autodist@mambasoft.it> 0.9.0-1mamba
- automatic version update by autodist

* Thu May 12 2011 Automatic Build System <autodist@mambasoft.it> 0.8.4.0-1mamba
- automatic update by autodist

* Fri Apr 29 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-12mamba
- Added patch reconnect_if_modem to avoid disabling modems after first failure

* Wed Apr 27 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-11mamba
- enable ifcfg-rh plugin

* Thu Feb 10 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-10mamba
- added requirement for dbus

* Tue Feb 08 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-9mamba
- activate service on install

* Fri Feb 04 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-8mamba
- added virtual requirement for dhcpclient

* Mon Jan 31 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-7mamba
- added patch to disable wireless scan if connected (http://nilvec.com/disable-scanning-in-networkmanager-when-connected/)

* Fri Jan 28 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-6mamba
- install main configuration file (fixes system connection configuration)

* Thu Jan 13 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-5mamba
- create VPN and system-connections directory in configuration dir

* Sun Dec 19 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-4mamba
- added patch to suppress weird log messages about file existence when writing connections

* Thu Dec 09 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-3mamba
- added policykit configuration for system-wide settings

* Thu Dec 02 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.2-2mamba
- rebuilt with debug package
- added patch that fixes a startup crash when checking wired connections

* Mon Nov 08 2010 Automatic Build System <autodist@mambasoft.it> 0.8.2-1mamba
- automatic update to 0.8.2 by autodist

* Mon Jul 26 2010 Automatic Build System <autodist@mambasoft.it> 0.8.1-1mamba
- automatic update to 0.8.1 by autodist

* Mon Mar 15 2010 Automatic Build System <autodist@mambasoft.it> 0.8-1mamba
- automatic update to 0.8 by autodist

* Tue Nov 24 2009 Automatic Build System <autodist@mambasoft.it> 0.7.2-1mamba
- automatic update to 0.7.2 by autodist

* Sun Apr 19 2009 Automatic Build System <autodist@mambasoft.it> 0.7.1-1mamba
- automatic update by autodist

* Sat Apr 04 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 0.7.0.99-1mamba
- automatic update by autodist

* Sat Feb 21 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 0.7.0.97-1mamba
- automatic update by autodist

* Tue Dec 02 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.7.0-2mamba
- update to released version

* Fri Jun 13 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.7.0-1mamba
- update to 0.7.0 (svn)

* Fri Jun 13 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.5-3mamba
- added libnm and libnm-devel subpackages

* Mon Jul 16 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.5-2mamba
- rebuilt against wireless_tools 29

* Tue Jul 10 2007 Aleph0 <aleph0@openmamba.org> 0.6.5-1mamba
- update to 0.6.5
- run ldconfig
- dropped patch for dbus: merged upstream
- added missing build requirement

* Fri Apr 06 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 0.6.4-1mamba
- update to version 0.6.4 by autospec

* Fri Mar 10 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 0.5.0-1qilnx
- update to version 0.5.0 by autospec

* Sat Sep 03 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.4-1qilnx
- package created by autospec
